@@ -1,12 +1,15 @@
 package HTTP::Engine::Interface;
-use Mouse;
+use Any::Moose;
+use Any::Moose (
+    '::Util' => [qw/apply_all_roles/],
+);
 
 my $ARGS;
 
 sub init_class {
     my $klass = shift;
-    my $meta = Mouse::Meta::Class->initialize($klass);
-    $meta->superclasses('Mouse::Object')
+    my $meta = any_moose('::Meta::Class')->initialize($klass);
+    $meta->superclasses(any_moose('::Object'))
       unless $meta->superclasses;
 
     no strict 'refs';
@@ -33,7 +36,12 @@ sub import {
 
     init_class($caller);
 
-    Mouse->export_to_level( 1 );
+    if (Any::Moose::is_moose_loaded()) {
+        Moose->import({ into_level => 1 });
+    }
+    else {
+        Mouse->export_to_level( 1 );
+    }
 }
 
 # fix up Interface.
@@ -48,7 +56,7 @@ sub __INTERFACE__ {
     _setup_builder($caller, $builder);
     _setup_writer($caller,  $writer);
 
-    Mouse::Util::apply_all_roles($caller, 'HTTP::Engine::Role::Interface');
+    apply_all_roles($caller, 'HTTP::Engine::Role::Interface');
 
     $caller->meta->make_immutable(inline_destructor => 1);
 
@@ -59,21 +67,20 @@ sub _setup_builder {
     my ($caller, $builder ) = @_;
     $builder = ($builder =~ s/^\+(.+)$//) ? $1 : "HTTP::Engine::RequestBuilder::$builder";
     unless ($builder->can('meta')) {
-        Mouse::load_class($builder);
+        Any::Moose::load_class($builder);
         $@ and die $@;
     }
-    my $instance = $builder->new;
 
-    no strict 'refs';
-    *{"$caller\::request_builder"} = sub { $instance };
+    my $instance = $builder->new;
+    $caller->meta->add_method(request_builder => sub { $instance });
 }
 
 sub _setup_writer {
     my ($caller, $args) = @_;
 
     my $writer = _construct_writer($caller, $args)->new;
-    no strict 'refs';
-    *{"$caller\::response_writer"} = sub { $writer };
+    
+    $caller->meta->add_method(response_writer => sub { $writer });
 }
 
 sub _construct_writer {
@@ -82,36 +89,39 @@ sub _construct_writer {
     my $writer = $caller . '::ResponseWriter';
     init_class($writer);
 
-    {
-        no strict 'refs';
+    {   
+        $writer->meta->make_mutable 
+            if Any::Moose::is_moose_loaded() 
+            && $writer->meta->is_immutable;        
 
         my @roles;
         my $apply = sub { push @roles, "HTTP::Engine::Role::ResponseWriter::$_[0]" };
         if ($args->{finalize}) {
-            *{"$writer\::finalize"} = $args->{finalize};
+            $writer->meta->add_method(finalize => $args->{finalize});               
         } else {
             if ($args->{response_line}) {
                 $apply->('ResponseLine');
             }
             if (my $code = $args->{output_header}) {
-                *{"$writer\::output_header"} = $code;
+                $writer->meta->add_method(output_header => $code);
             } else {
                 $apply->('OutputHeader');
             }
             if (my $code = $args->{output_body}) {
-                *{"$writer\::output_body"} = $code;
+                $writer->meta->add_method(output_body => $code);
             } else {
                 $apply->('OutputBody');
             }
             if (my $code = $args->{write}) {
-                *{"$writer\::write"} = $code;
+                $writer->meta->add_method(write => $code);
             } else {
                 $apply->('WriteSTDOUT');
             }
             $apply->('Finalize');
         }
+
         for my $role (@roles, 'HTTP::Engine::Role::ResponseWriter') {
-            Mouse::Util::apply_all_roles($writer, $role);
+            apply_all_roles($writer, $role);
         }
     }
 
@@ -122,11 +132,24 @@ sub _construct_writer {
         $writer->meta->add_around_method_modifier( $around => $args->{around}->{$around} );
     }
     for my $attribute (keys %{ $args->{attributes} || {} }) {
-        Mouse::Meta::Attribute->create( $writer->meta, $attribute,
-            %{ $args->{attributes}->{$attribute} } );
+        if (Any::Moose::is_moose_loaded()) {
+            $writer->meta->add_attribute( 
+                $attribute,
+                %{ $args->{attributes}->{$attribute} }
+            )
+        }
+        else {
+            Mouse::Meta::Attribute->create( 
+                $writer->meta, 
+                $attribute,
+                %{ $args->{attributes}->{$attribute} } 
+            );
+        }
     }
 
-    $writer->meta->make_immutable(inline_destructor => 1);
+    # FIXME
+    $writer->meta->make_immutable(inline_destructor => 1)
+        unless Any::Moose::is_moose_loaded();
 
     return $writer;
 }
