@@ -1,11 +1,11 @@
 package HTTP::Engine::Response;
-use Mouse;
+use Any::Moose;
 
 use HTTP::Status ();
 use HTTP::Headers::Fast;
 use HTTP::Engine::Types::Core qw( Header );
 
-# Mouse role merging is borked with attributes
+# Mouse, Moose role merging is borked with attributes
 #with qw(HTTP::Engine::Response);
 
 sub BUILD {
@@ -79,7 +79,7 @@ sub as_http_response {
     );
 }
 
-no Mouse;
+no Any::Moose;
 1;
 __END__
 
